[run]
omit =
  setup.py,
  *_test.py,
  tests.py,
  testapp/*
  tests/*,
  conftest.py

[report]
precision = 2
show_missing = True
exclude_lines =
    # Don't complain if tests don't hit defensive assertion code:
    raise NotImplementedError
    # Ignore type checking conditions
    if TYPE_CHECKING:
