{% include "snippets/badges.tpl" %}
{% include "snippets/tagline.tpl"%}
{% include "snippets/links.tpl" %}

{% include "snippets/content.tpl" %}
{% include "snippets/installation.tpl" %}
{% include "snippets/contribute.tpl" %}
{% include "snippets/publish.tpl" %}
{% include "snippets/maintenance.tpl" %}
